yakumo.cinder.v1.volume.Resource

Package yakumo :: Package cinder :: Package v1 :: Module volume :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for volumes on Block Storage V1 API

Instance Methods | [hide private]
dict |
get_metadata(self) Get metadata of a volume | source code
None |
set_metadata(self, **metadata) Update metadata of a volume | source code
None |
unset_metadata(self, *keys) Delete metadata of a volume | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _stable_state = ``[``'``available``'``,` `'``in-use``'``,` `'``error``'``,` `'``error_deleti``...``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get_metadata(self) | source code
Get metadata of a volume Returns: dict Metadata

### set_metadata(self, **metadata) | source code
Update metadata of a volume Parameters: `metadata` (dict) - key=value style. Returns: None

### unset_metadata(self, *keys) | source code
Delete metadata of a volume Parameters: `key` - key of the metadata `keys` ([str]) Returns: None

Class Variable Details | [hide private]

  ### _stable_state Value:
      ['available', 'in-use', 'error', 'error_deleting']